import passport from 'passport';
import { Strategy as LocalStrategy } from 'passport-local';
import express, { Request, Response } from 'express';
import { prisma, __path, log, config, app } from '../../index.js';

// Middleware Imports
import { checkAuthentication } from '../../middleware/auth.mw.js'

/* Configure password authentication strategy.
 *
 * The `LocalStrategy` authenticates users by verifying a username and password.
 * The strategy parses the username and password from the request and calls the
 * `verify` function.
 *
 * The `verify` function queries the database for the user record and verifies
 * the password by hashing the password supplied by the user and comparing it to
 * the hashed password stored in the database.  If the comparison succeeds, the
 * user is authenticated; otherwise, not.
 */
passport.use(
	new LocalStrategy(function verify(username, password, cb) {
		//log.auth.debug('LocalStrategy:', username, password);

		for (const [user, pass] of Object.entries(config.global.auth.local.users)) {
			//log.auth.debug('Loop(REQ):', username, password);
			//log.auth.debug('Loop(CFG):', user, pass);

			if (user.toLowerCase() === username.toLowerCase() && pass === password) {
				log.auth.debug('LocalStrategy: success');
				return cb(null, { username: username }); // This is the user object.
			}
		}
		log.auth.debug('LocalStrategy: failed');
		return cb(null, false, { message: 'Incorrect username or password.' });
	})
	/*
	1. If the user not found in DB,
	done (null, false)
	
	2. If the user found in DB, but password does not match, 
	done (null, false)
	
	3. If user found in DB and password match, 
	done (null, {authenticated_user})
	*/
);

/* Configure session management.
 *
 * When a login session is established, information about the user will be
 * stored in the session.  This information is supplied by the `serializeUser`
 * function, which is yielding the user ID and username.
 *
 * As the user interacts with the app, subsequent requests will be authenticated
 * by verifying the session.  The same user information that was serialized at
 * session establishment will be restored when the session is authenticated by
 * the `deserializeUser` function.
 *
 */
passport.serializeUser(function (user: any, cb) {
	process.nextTick(function () {
		// log.auth.debug('Called seriealizeUser');
		// log.auth.debug('user:', user);
		return cb(null, {
			username: user.username
		});
	});
});

passport.deserializeUser(function (user, cb) {
	process.nextTick(function () {
		// log.auth.debug('Called deseriealizeUser');
		return cb(null, user);
	});
});

// Route imports
import testRoute from './test.js';
import loginRoute from './login.js';
//import logoutRoute from './login.js'

// Router base is '/auth'
const Router = express.Router({ strict: false });

Router.route('/login').get(loginRoute.get);
Router.route('/login').post(passport.authenticate('local', { successRedirect: '/', failureRedirect: '/auth/login?failed' }));

Router.route('/test').get(checkAuthentication, testRoute.get);

export default Router;
